#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-aeson
version:              2.3.2
visibility:           public
id:                   hslua-aeson-2.3.2-52eH1ueBUaq4A4FidFgLl4
key:                  hslua-aeson-2.3.2-52eH1ueBUaq4A4FidFgLl4
license:              MIT
copyright:            © 2017-2026 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Allow aeson data types to be used with Lua.
description:
    This package provides instances to push and receive any
    datatype encodable as JSON to and from the Lua stack.

category:             Foreign
abi:                  5b00f3aeef44ce411256d31cf23a923d
exposed:              True
exposed-modules:      HsLua.Aeson
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-aeson-2.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-aeson-2.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-aeson-2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-aeson
hs-libraries:         HShslua-aeson-2.3.2-52eH1ueBUaq4A4FidFgLl4
depends:
    aeson-2.2.2.0-JRwGfw4G4faAdkvjZDffZf base-4.18.2.1
    bytestring-0.11.5.3 hslua-core-2.3.2-6bADJKxoFqjCjLTJ3KihbT
    hslua-marshalling-2.3.2-H1GvrMBlU13IaDlw5PKplr
    scientific-0.3.8.1-FfOn8C5pQ5M9kVwKQotP6m
    vector-0.13.2.0-Bce9rIW4lAD9r12sFleKX

haddock-interfaces:   /usr/share/doc/haskell-hslua-aeson/html/hslua-aeson.haddock
haddock-html:         /usr/share/doc/haskell-hslua-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

